<p align="center"><img src="https://rogervila.es/static/img/equipment-logo.png" alt="Equipment python framework" height="200" /></p>

[![PyPI version](https://badge.fury.io/py/equipment.svg)](https://badge.fury.io/py/equipment)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=rogervila_equipment&metric=alert_status)](https://sonarcloud.io/dashboard?id=rogervila_equipment)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=rogervila_equipment&metric=sqale_rating)](https://sonarcloud.io/dashboard?id=rogervila_equipment)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=rogervila_equipment&metric=coverage)](https://sonarcloud.io/dashboard?id=rogervila_equipment)

# Equipment

The root of your next python project

## Docs

Visit the [documentation website](https://equipment-python.vercel.app)

## License

This project is open-sourced software licensed under the [MIT license](https://opensource.org/licenses/MIT).

Equipment icons created by <a href="https://www.flaticon.com/free-icons/toolbox">Freepik - Flaticon</a>
